Welcome to slidge docs
======================

.. sidebar::

    Links

    - `Web site <https://slidge.im>`_
    - `Chat room <xmpp:slidge@conference.nicoco.fr?join>`_
    - `Issues <https://codeberg.org/slidge/slidge/issues>`_

Slidge is a python library to easily make
`Gateways <https://https://xmpp.org/extensions/xep-0100.html>`_
from
`XMPP <https://https://xmpp.org>`_
to other chat networks.
Gateways to
`Matrix, Telegram, Discord, WhatsApp (and other silos) <https://codeberg.org/explore/repos?q=slidge&topic=1>`_
have been built on top of it.


.. toctree::

   admin/index
   user/index
   dev/index
   glossary


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
